Enum PanicCode
Source #[repr(u16)]
pub enum PanicCode {
Show 37 variants
Unknown = 0,
ManuallyTriggeredPanic = 1,
InitFailure = 2,
InitProcessDied = 3,
InternalKernelError = 48,
UninitializedAccess = 49,
DoubleInitialization = 50,
IllegalInterrupt = 153,
DivideError = 256,
NmiHardwareFailure = 258,
Overflow = 260,
InvalidOpcode = 262,
DeviceNotAvail = 263,
DoubleFault = 264,
InvalidTss = 272,
SegmentNotPresent = 273,
StackSegmentFault = 274,
GeneralProtectionFault = 275,
PageFault = 276,
X87FloatingPoint = 278,
AlignmentCheck = 279,
MachineCheck = 280,
SimdFloatingPoint = 281,
Virtualization = 288,
VmmCommunicationException = 297,
SecurityException = 304,
NoValidMemMapEntry = 768,
DoubleFree = 769,
IllegalFree = 770,
OutOfMemory = 771,
OutOfVirtualMemory = 772,
MemoryMappingCollision = 773,
MisalignedAddress = 774,
InvalidPageOperation = 880,
NoWorkingInit = 1_024,
ProcessNotFound = 1_025,
MalformedPsf2Font = 4_096,
}
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.